# Example Package

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

**This text should be Bold.**

*This text should be in Italics.*

[Description of link](http://google.com)
